/*
 * Copyright 2012 metArch
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.metarch.timer.util;

import java.util.Comparator;

import org.metarch.timer.model.Timer;

/**
 * Contains a set of static methods returning comparators to sort the
 * set of timers to your liking.
 *
 * @author Niels Krijger <niels@kryger.nl>
 */
public class TimerComparator {
    
    /**
     * Orders the timers in alphabetic order.
     * 
     * @return
     */
    public static Comparator<Timer> sortByName() {
        return new Comparator<Timer>() {
            @Override
            public int compare(Timer o1, Timer o2) {
                return (o1.getTag()).compareTo(o2.getTag());
            }
        };
    }

    /**
     * Orders the timers from shortest running to longest running.
     * 
     * @return
     */
    public static Comparator<Timer> sortTotalTimeAscending() {
        return new Comparator<Timer>() {
            @Override
            public int compare(Timer o1, Timer o2) {
                int result = (int) (o1.getTotalTime() - o2.getTotalTime());
                return (result == 0) ? -1 : result;
            }
        };
    }
    
    /**
     * Orders the timers from longest running to shortest running.
     * 
     * @return
     */
    public static Comparator<Timer> sortTotalTimeDescending() {
        return new Comparator<Timer>() {
            @Override
            public int compare(Timer o1, Timer o2) {
                int result = (int) (o2.getTotalTime() - o1.getTotalTime());
                return (result == 0) ? -1 : result;
            }
        };
    }
}